---
title: "Getting started"
description: "Learn how to get your first Keystone project up and running using the `create-keystone-app` Command Line Interface."
---

![A terminal with the output of create-keystone-app](/assets/getting-started/cover.svg)

[`create-keystone-app`](https://github.com/keystonejs/create-keystone-app) is a CLI app that makes it easier for you initiate a Keystone project.
It generates some files for you and installs all the dependencies you need to run the Admin UI and start using the [GraphQL API](/docs/graphql/overview).

## Quick Start

```sh
yarn create keystone-app
cd my-app
yarn dev
```

## Installing a Keystone instance

Open your preferred shell and make sure you’re in the folder you want to create your new project in.
`create-keystone-app` will generate a new folder with your new Keystone files in it.

### Yarn

Use [`yarn create`](https://classic.yarnpkg.com/en/docs/cli/create/):

```sh
cd your/path/
yarn create keystone-app
```

### npm

Use [`npm init`](https://docs.npmjs.com/cli/v7/commands/npm-init):

```sh
cd your/path/
npm init keystone-app
```

{% hint kind="warn" %}
`npm init "<initializer>"` is available in npm 6+
{% /hint %}

### npx

Use npm's [`npx`](https://docs.npmjs.com/cli/v7/commands/npx):

```sh
cd your/path/
npx create-keystone-app
```

{% hint kind="warn" %}
`npx` comes with npm 5.2+
{% /hint %}

## Naming your app

The CLI will ask you to name your app. Once named, it will create a new SQLite database.

{% hint kind="warn" %}
You can switch to another database such as PostgreSQL once your project is created, check out the docs on [Database Setup](https://keystonejs.com/docs/config/config#db).
{% /hint %}

## Opening your shiny new Admin UI

You can now `cd` into the folder that was created for you and start Keystone:

```sh
cd my-app
yarn dev
```

This will generate the Admin UI pages via [Next.js](https://nextjs.org/) on <http://localhost:3000>. When you visit the Admin UI for the first time you will be presented with a handy screen that asks you to create a user:

![The welcome screen giving you the ability the create a new user to log into the Admin UI](/assets/getting-started/welcome-screen.png)

Go ahead and create your first user. The email address and password will be used to login to Keystone’s Admin UI. Once you've created your user, you’ll be logged in to a new Keystone Admin UI that comes with two [lists](/docs/config/config#lists).
From here you can explore and interact with the data in your system, and understand how Keystone’s schema relates to your GraphQL API which you can explore at <http://localhost:3000/api/graphql>.

![The Admin UI of Keystone showing the two lists: User and Posts](/assets/getting-started/adminui.png)

## Output

Keytone creates the following files in your newly generated folder. The most important ones are [`keystone.ts`](/docs/config/config) and [`schema.ts`](/docs/config/lists).

```sh
.
├── auth.ts        # Authentication configuration for Keystone
├── keystone.ts    # The main entry file for configuring Keystone
├── node_modules   # Your dependencies
├── package.json   # Your package.json with four scripts prepared for you
├── README.md      # Additional info to help you get started
├── schema.graphql # GraphQL schema (automatically generated by Keystone)
├── schema.prisma  # Prisma configuration (automatically generated by Keystone)
├── schema.ts      # Where you design your data schema
├── tsconfig.json  # Your typescript config
└── yarn.lock      # Your yarn lock file
```

## Scripts

`package.json` includes the following npm scripts you can run locally:

- [`dev`](/docs/guides/cli#dev) runs Keystone in **development** mode at <http://localhost:3000>.
- [`start`](/docs/guides/cli#start) runs Keystone in **production** mode.
- [`build`](/docs/guides/cli#build) will build the project and is required to be run before `start`.
- [`postinstall`](/docs/guides/cli#postinstall) ensures files that Keystone generates exist and are kept up to date.

{% hint kind="tip" %}
Read more about the CLI in our [command line guides](/docs/guides/cli).
{% /hint %}

## Where to next?

- Customise Keystone with the [System Configuration API](./config/config).
- Add fields and relationships using [Lists API](/docs/config/lists).
- Use a different database with the [Config API](/docs/config/config#db).

## Related resources

{% related-content %}
{% well
heading="Keystone CLI Guide"
href="/docs/guides/cli" %}
Keystone’s CLI helps you develop, build, and deploy projects. This guide explains all you need to standup a new backend in the terminal.
{% /well %}
{% well
heading="Lists API Reference"
href="/docs/config/lists" %}
The API to configure your options used with the `list()` function.
{% /well %}
{% well
heading="Config API Reference"
href="/docs/config/config" %}
The API to configure all the parts parts of your Keystone system.
{% /well %}
{% well
heading="DB API Reference"
href="/docs/config/config#db" %}
Configure Keystone to use another database to store data in your system.
{% /well %}
{% /related-content %}
